from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from django_comments_xtd.admin import XtdCommentsAdmin

from .models import Threat


class ThreatAdmin(XtdCommentsAdmin):
    list_display = (
        "submit_date",
        # "title",
        # "cid",
        "name",
        # "content_type",
        # "object_pk",
        "followup",
        "is_public",
        "is_removed",
    )
    list_display_links = (
        "submit_date",
        # "title",
    )
    list_filter = ("is_public", "is_removed", "followup")
    fieldsets = (
        (
            None,
            {
                "fields": (
                    "content_type",
                    "object_pk",
                    "site",
                ),
            },
        ),
        (
            _("Content"),
            {
                "fields": (
                    # "title",
                    "user",
                    "user_name",
                    "user_email",
                    "user_url",
                    "comment",
                    "followup",
                ),
            },
        ),
        (
            _("Metadata"),
            {
                "fields": (
                    "submit_date",
                    "ip_address",
                    "is_public",
                    "is_removed",
                ),
            },
        ),
    )


admin.site.register(Threat, ThreatAdmin)



# Generated by Django 3.2.12 on 2022-03-24 13:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('django_comments_xtd', '0008_auto_20200920_2037'),
    ]

    operations = [
        migrations.CreateModel(
            name='Threat',
            fields=[
                ('xtdcomment_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='django_comments_xtd.xtdcomment')),
            ],
            options={
                'verbose_name': 'comment',
                'verbose_name_plural': 'comments',
                'ordering': ('submit_date',),
                'permissions': [('can_moderate', 'Can moderate comments')],
                'abstract': False,
            },
            bases=('django_comments_xtd.xtdcomment',),
        ),
    ]



from django.urls import include, path
from django.utils.translation import gettext_lazy as _

from simpel_routers.viewsets import ReadOnlyViewSet, login_required_m

from .models import Threat


class ThreatViewSet(ReadOnlyViewSet):
    model = Threat
    filterset_fields = ["comment"]
    paginate_by = 10

    def get_queryset(self):
        qs = super().get_queryset()
        return qs.filter(user=self.request.user)

    @login_required_m
    def index_view(self, request):
        self.request = request
        kwargs = {
            "viewset": self,
            "title": _("My Discuss"),
        }
        view_class = self.index_view_class
        return view_class.as_view(**kwargs)(request)

    def get_urls(self):
        urls = super().get_urls()
        urls += [
            path("comments/", include("django_comments_xtd.urls"))
        ]
        return urls



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class SimpelDiscussConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'simpel_discuss'
    app_label = 'simpel_discuss'
    verbose_name = _("Discuss")
    icon = "comment-quote-outline"



import logging

from django_comments_xtd.forms import XtdCommentForm

from simpel_discuss.settings import discuss_settings

logger = logging.getLogger(__name__)

try:
    from snowpenguin.django.recaptcha2.fields import ReCaptchaField
    from snowpenguin.django.recaptcha2.widgets import ReCaptchaWidget

    CAPTCHA_INSTALLED = True
except ImportError:
    if discuss_settings.CAPTCHA_ENABLED:
        logger.warning("discuss captcha feature enabled, but django-recaptcha2 is not installed!")
    CAPTCHA_INSTALLED = False


class ThreatForm(XtdCommentForm):
    captcha_enabled = discuss_settings.CAPTCHA_ENABLED
    # title = forms.CharField(
    #     max_length=256,
    #     widget=forms.TextInput(attrs={'placeholder': _('title')})
    # )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        if self.captcha_enabled and CAPTCHA_INSTALLED:
            self.fields["captcha"] = ReCaptchaField(widget=ReCaptchaWidget())

    def get_comment_create_data(self, site_id=None):
        data = super(ThreatForm, self).get_comment_create_data(site_id=site_id)
        # data.update({
        #     'title': self.cleaned_data['title'],
        # })
        return data
